@@ -1,11 +1,11 @@
 
 /* Generated data (by glib-mkenums) */
 
+#include <config.h>
 #include <glib-object.h>
 #include "libgnometypebuiltins.h"
 
 
-
 /* enumerations from "gnome-triggers.h" */
 static const GEnumValue _gnome_trigger_type_values[] = {
   { GTRIG_NONE, "GTRIG_NONE", "none" },
@@ -27,7 +27,6 @@ gnome_trigger_type_get_type (void)
 }
 
 
-
 /* enumerations from "gnome-program.h" */
 static const GEnumValue _gnome_file_domain_values[] = {
   { GNOME_FILE_DOMAIN_UNKNOWN, "GNOME_FILE_DOMAIN_UNKNOWN", "unknown" },
@@ -58,7 +57,6 @@ gnome_file_domain_get_type (void)
 }
 
 
-
 /* enumerations from "gnome-help.h" */
 static const GEnumValue _gnome_help_error_values[] = {
   { GNOME_HELP_ERROR_INTERNAL, "GNOME_HELP_ERROR_INTERNAL", "internal" },
@@ -78,7 +76,6 @@ gnome_help_error_get_type (void)
 }
 
 
-
 /* enumerations from "gnome-url.h" */
 static const GEnumValue _gnome_url_error_values[] = {
   { GNOME_URL_ERROR_PARSE, "GNOME_URL_ERROR_PARSE", "parse" },
@@ -87,6 +84,7 @@ static const GEnumValue _gnome_url_error_values[] = {
   { GNOME_URL_ERROR_NO_DEFAULT, "GNOME_URL_ERROR_NO_DEFAULT", "no-default" },
   { GNOME_URL_ERROR_NOT_SUPPORTED, "GNOME_URL_ERROR_NOT_SUPPORTED", "not-supported" },
   { GNOME_URL_ERROR_VFS, "GNOME_URL_ERROR_VFS", "vfs" },
+  { GNOME_URL_ERROR_CANCELLED, "GNOME_URL_ERROR_CANCELLED", "cancelled" },
   { 0, NULL, NULL }
 };
 
@@ -102,6 +100,5 @@ gnome_url_error_get_type (void)
 }
 
 
-
 /* Generated data ends here */
 
